============
Installation
============

At the command line::

    $ easy_install super_state_machine

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv super_state_machine
    $ pip install super_state_machine